@@ -192,53 +192,107 @@ print.cbc_priors <- function(x, ...) {
 #' @return Returns the input `cbc_design` object invisibly (class: c("cbc_design", "data.frame")). This function is called for its side effect of printing a concise summary of the CBC design to the console, including design method, structure, D-error metrics, profile usage, and a preview of the design data.
 #' @export
 print.cbc_design <- function(x, ...) {
-    # Extract basic information
+    # Check if this looks like actual design data or a transformed data frame
+    # If key columns are missing, just print as data frame
+    has_required_cols <- all(c("obsID", "altID") %in% names(x))
+
+    if (!has_required_cols) {
+        # This is a transformed data frame (e.g., from dplyr operations)
+        # Print as a regular data frame
+        class(x) <- setdiff(class(x), "cbc_design")
+        return(print(x, ...))
+    }
+
+    # Extract basic information (may be NULL if reconstructed)
     params <- attr(x, "design_params")
     summary_info <- attr(x, "design_summary")
+    encoding <- attr(x, "encoding") %||% "standard"
 
-    # Basic structure info
-    cat(sprintf("Design method: %s\n", params$method))
-    cat(sprintf(
-        "Structure: %d respondents \u00D7 %d questions \u00D7 %d alternatives",
-        params$n_resp,
-        params$n_q,
-        params$n_alts
-    ))
+    # Infer basic structure if params missing
+    if (is.null(params)) {
+        has_resp_id <- "respID" %in% names(x)
+        has_block_id <- "blockID" %in% names(x)
 
-    if (params$n_blocks > 1) {
-        cat(sprintf(" [%d blocks]", params$n_blocks))
-    }
-    cat("\n")
+        n_resp <- if (has_resp_id) max(x$respID, na.rm = TRUE) else 1
+        n_blocks <- if (has_block_id) max(x$blockID, na.rm = TRUE) else 1
+        n_q <- max(x$qID, na.rm = TRUE)
+        n_alts <- max(x$altID, na.rm = TRUE)
 
-    # Show interaction information
-    if (!is.null(params$has_interactions) && params$has_interactions) {
+        cat("Design method: unknown\n")
+        cat(sprintf("Encoding: %s\n", encoding))
         cat(sprintf(
-            "Interactions: %d interaction terms used in design search\n",
-            params$n_interactions
+            "Structure: %d respondents \u00D7 %d questions \u00D7 %d alternatives",
+            n_resp,
+            n_q,
+            n_alts
         ))
-    }
 
-    # Profile usage
-    cat(sprintf(
-        "Profile usage: %d/%d (%.1f%%)\n",
-        summary_info$n_profiles_used,
-        summary_info$n_profiles_available,
-        summary_info$profile_usage_rate * 100
-    ))
-
-    # D-error (show best available)
-    if (!is.null(params$d_error_prior)) {
-        cat(sprintf("D-error: %.6f", params$d_error_prior))
-        if (!is.null(params$has_interactions) && params$has_interactions) {
-            cat(" (with interactions)")
+        if (n_blocks > 1) {
+            cat(sprintf(" [%d blocks]", n_blocks))
         }
         cat("\n")
-    } else if (!is.null(params$d_error_null)) {
-        cat(sprintf("D-error: %.6f\n", params$d_error_null))
+
+        # Profile usage
+        n_profiles_used <- length(unique(x$profileID[x$profileID != 0]))
+        n_profiles_available <- max(x$profileID, na.rm = TRUE)
+        cat(sprintf(
+            "Profile usage: %d/%d (%.1f%%)\n",
+            n_profiles_used,
+            n_profiles_available,
+            (n_profiles_used / n_profiles_available) * 100
+        ))
+    } else {
+        # Full information available
+        cat(sprintf("Design method: %s\n", params$method))
+        cat(sprintf("Encoding: %s\n", encoding))
+        cat(sprintf(
+            "Structure: %d respondents \u00D7 %d questions \u00D7 %d alternatives",
+            params$n_resp,
+            params$n_q,
+            params$n_alts
+        ))
+
+        if (params$n_blocks > 1) {
+            cat(sprintf(" [%d blocks]", params$n_blocks))
+        }
+        cat("\n")
+
+        # Show interaction information
+        if (!is.null(params$has_interactions) && params$has_interactions) {
+            cat(sprintf(
+                "Interactions: %d interaction terms used in design search\n",
+                params$n_interactions
+            ))
+        }
+
+        # Profile usage
+        cat(sprintf(
+            "Profile usage: %d/%d (%.1f%%)\n",
+            summary_info$n_profiles_used,
+            summary_info$n_profiles_available,
+            summary_info$profile_usage_rate * 100
+        ))
+
+        # D-error (show best available)
+        if (!is.null(params$d_error_prior)) {
+            cat(sprintf("D-error: %.6f", params$d_error_prior))
+            if (!is.null(params$has_interactions) && params$has_interactions) {
+                cat(" (with interactions)")
+            }
+            cat("\n")
+        } else if (!is.null(params$d_error_null)) {
+            cat(sprintf("D-error: %.6f\n", params$d_error_null))
+        }
     }
 
     cat("\n")
-    cat("\U0001F4A1 Use cbc_inspect() for a more detailed summary\n\n")
+    cat("\U0001F4A1 Use cbc_inspect() for a more detailed summary\n")
+    if (encoding != "standard") {
+        cat(
+            "\U0001F4A1 Use cbc_encode(design, 'standard') to view categorical format\n"
+        )
+    }
+    cat("\n")
 
     # Sample data
     cat("First few rows of design:\n")
@@ -260,11 +314,23 @@ print.cbc_design <- function(x, ...) {
 #' @return Returns the input `cbc_choices` object invisibly (class: c("cbc_choices", "data.frame")). This function is called for its side effect of printing a formatted summary of the CBC choice data to the console, including choice task structure, simulation details, choice rates by alternative, and a preview of the choice data.
 #' @export
 print.cbc_choices <- function(x, ...) {
+    # Check if this looks like actual choice data or a transformed data frame
+    # If key columns are missing, just print as data frame
+    has_required_cols <- all(c("obsID", "choice") %in% names(x))
+
+    if (!has_required_cols) {
+        # This is a transformed data frame (e.g., from dplyr operations)
+        # Print as a regular data frame
+        class(x) <- setdiff(class(x), "cbc_choices")
+        return(print(x, ...))
+    }
+
     cat("CBC Choice Data\n")
     cat("===============\n")
 
     # Get choice info
     choice_info <- attr(x, "choice_info")
+    encoding <- attr(x, "encoding") %||% "standard"
 
     # Basic structure
     n_obs <- max(x$obsID, na.rm = TRUE)
@@ -272,6 +338,7 @@ print.cbc_choices <- function(x, ...) {
     n_resp <- if ("respID" %in% names(x)) max(x$respID, na.rm = TRUE) else 1
     n_choices <- sum(x$choice, na.rm = TRUE)
 
+    cat(sprintf("Encoding: %s\n", encoding))
     cat(sprintf("Observations: %d choice tasks\n", n_obs))
     cat(sprintf("Alternatives per task: %d\n", n_alts))
     if (n_resp > 1) {
@@ -318,6 +385,12 @@ print.cbc_choices <- function(x, ...) {
         cat(sprintf("\nNo-choice rate: %.1f%%\n", no_choice_rate * 100))
     }
 
+    if (encoding != "standard") {
+        cat(
+            "\n\U0001F4A1 Use cbc_encode(choices, 'standard') to view categorical format\n"
+        )
+    }
+
     cat("\nFirst few rows:\n")
 
     # Remove class temporarily to avoid infinite recursion
@@ -388,12 +461,15 @@ print.cbc_inspection <- function(x, ...) {
 
 print_structure_section <- function(structure_data, verbose) {
     cat(sprintf("Method: %s\n", structure_data$method))
-    cat(sprintf(
-        "Created: %s\n",
-        format(structure_data$created_at, "%Y-%m-%d %H:%M:%S")
-    ))
 
-    if (verbose) {
+    if (!is.na(structure_data$created_at)) {
+        cat(sprintf(
+            "Created: %s\n",
+            format(structure_data$created_at, "%Y-%m-%d %H:%M:%S")
+        ))
+    }
+
+    if (verbose && !is.na(structure_data$generation_time)) {
         cat(sprintf(
             "Generation time: %.3f seconds\n",
             structure_data$generation_time
@@ -424,7 +500,7 @@ print_structure_section <- function(structure_data, verbose) {
         }
     }
 
-    if (verbose && !is.null(structure_data$optimization_attempts)) {
+    if (verbose && !is.na(structure_data$optimization_attempts)) {
         cat(sprintf(
             "Optimization attempts: %d\n",
             structure_data$optimization_attempts
@@ -434,26 +510,44 @@ print_structure_section <- function(structure_data, verbose) {
 
 print_efficiency_section <- function(efficiency_data, verbose) {
     # D-error information
-    if (efficiency_data$method != 'random') {
-        if (!is.null(efficiency_data$d_error_prior)) {
+    if (
+        efficiency_data$method != 'random' &&
+            efficiency_data$method != 'unknown'
+    ) {
+        has_d_error <- FALSE
+
+        if (
+            !is.null(efficiency_data$d_error_prior) &&
+                !is.na(efficiency_data$d_error_prior)
+        ) {
             cat(sprintf(
                 "D-error (with priors): %.6f\n",
                 efficiency_data$d_error_prior
             ))
+            has_d_error <- TRUE
         }
-        if (!is.null(efficiency_data$d_error_null)) {
+        if (
+            !is.null(efficiency_data$d_error_null) &&
+                !is.na(efficiency_data$d_error_null)
+        ) {
             cat(sprintf(
                 "D-error (null model): %.6f\n",
                 efficiency_data$d_error_null
             ))
+            has_d_error <- TRUE
+        }
+        if (has_d_error) {
+            cat("(Lower values indicate more efficient designs)\n\n")
         }
-        cat("(Lower values indicate more efficient designs)\n\n")
     } else {
-        cat("D-error calculation not available for random designs\n")
+        cat("D-error calculation not available for this design\n")
     }
 
     # Quality metrics if available
-    if (!is.na(efficiency_data$balance_score)) {
+    if (
+        !is.null(efficiency_data$balance_score) &&
+            !is.na(efficiency_data$balance_score)
+    ) {
         cat(sprintf(
             "Overall balance score: %.3f (higher is better)\n",
             efficiency_data$balance_score
@@ -463,7 +557,11 @@ print_efficiency_section <- function(efficiency_data, verbose) {
             efficiency_data$overlap_score
         ))
 
-        if (verbose && !is.na(efficiency_data$profiles_used)) {
+        if (
+            verbose &&
+                !is.null(efficiency_data$profiles_used) &&
+                !is.na(efficiency_data$profiles_used)
+        ) {
             cat(sprintf(
                 "  Profiles used: %d/%d\n",
                 efficiency_data$profiles_used,
@@ -473,6 +571,52 @@ print_efficiency_section <- function(efficiency_data, verbose) {
     }
 }
 
+print_encoding_section <- function(encoding_data, verbose) {
+    encoding_names <- c(
+        standard = "Standard (categorical)",
+        dummy = "Dummy-coded",
+        effects = "Effects-coded"
+    )
+
+    cat("Format: ", encoding_names[encoding_data$encoding], sep = "")
+
+    # Show which variables are categorical
+    if (
+        !is.null(encoding_data$categorical_variables) &&
+            length(encoding_data$categorical_variables) > 0
+    ) {
+        cat(sprintf(
+            " (%s)",
+            paste(encoding_data$categorical_variables, collapse = ", ")
+        ))
+    }
+    cat("\n")
+
+    if (verbose && !is.null(encoding_data$categorical_details)) {
+        cat("\nCategorical variable details:\n")
+        for (var in names(encoding_data$categorical_details)) {
+            details <- encoding_data$categorical_details[[var]]
+            cat(sprintf(
+                "  %s: %s (reference: %s)\n",
+                var,
+                paste(details$levels, collapse = ", "),
+                details$reference_level
+            ))
+        }
+    }
+
+    # Show encoding options
+    if (encoding_data$encoding != "standard") {
+        cat(
+            "\U0001F4A1 Use cbc_encode(design, 'standard') to convert to categorical format\n"
+        )
+    } else {
+        cat(
+            "\U0001F4A1 Use cbc_encode() to convert to dummy or effects coding\n"
+        )
+    }
+}
+
 print_balance_section <- function(balance_data, verbose) {
     if (!is.null(balance_data$overall_balance)) {
         cat(sprintf(
@@ -593,46 +737,6 @@ print_overlap_section <- function(overlap_data, verbose) {
     }
 }
 
-print_encoding_section <- function(encoding_data, verbose) {
-    if (encoding_data$is_dummy_coded) {
-        cat("Format: Dummy-coded")
-
-        # Show which variables are categorical
-        if (
-            !is.null(encoding_data$categorical_variables) &&
-                length(encoding_data$categorical_variables) > 0
-        ) {
-            cat(sprintf(
-                " (%s)",
-                paste(encoding_data$categorical_variables, collapse = ", ")
-            ))
-        }
-        cat("\n")
-
-        if (verbose && !is.null(encoding_data$categorical_details)) {
-            cat("\nCategorical variable details:\n")
-            for (var in names(encoding_data$categorical_details)) {
-                details <- encoding_data$categorical_details[[var]]
-                cat(sprintf(
-                    "  %s: %s (reference: %s)\n",
-                    var,
-                    paste(details$levels, collapse = ", "),
-                    details$reference_level
-                ))
-            }
-        }
-
-        # Show decode option if no no-choice
-        if (!encoding_data$no_choice) {
-            cat(
-                "\U0001F4A1 Use cbc_decode_design() to convert to categorical format\n"
-            )
-        }
-    } else {
-        cat("Format: Categorical\n")
-    }
-}
-
 #' Print method for cbc_comparison objects
 #' @param x A cbc_comparison object
 #' @param ... Additional arguments passed to print
@@ -1050,3 +1154,174 @@ summary.cbc_power <- function(object, power_threshold = 0.8, ...) {
     cat("\n")
     invisible(object)
 }
+
+# ============================================================================
+# Attribute preservation methods for cbc_profiles
+# ============================================================================
+
+#' @export
+`[.cbc_profiles` <- function(x, i, j, drop = FALSE) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[")
+
+    if (is.data.frame(result)) {
+        class(result) <- c("cbc_profiles", "data.frame")
+
+        custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+        for (attr_name in custom_attr_names) {
+            attr(result, attr_name) <- custom_attrs[[attr_name]]
+        }
+    }
+
+    return(result)
+}
+
+#' @export
+`[<-.cbc_profiles` <- function(x, i, j, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[<-")
+
+    class(result) <- c("cbc_profiles", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
+
+#' @export
+`names<-.cbc_profiles` <- function(x, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("names<-")
+
+    class(result) <- c("cbc_profiles", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
+
+# ============================================================================
+# Attribute preservation methods for cbc_design
+# ============================================================================
+
+#' @export
+`[.cbc_design` <- function(x, i, j, drop = FALSE) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[")
+
+    if (is.data.frame(result)) {
+        class(result) <- c("cbc_design", "data.frame")
+
+        custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+        for (attr_name in custom_attr_names) {
+            attr(result, attr_name) <- custom_attrs[[attr_name]]
+        }
+    }
+
+    return(result)
+}
+
+#' @export
+`[<-.cbc_design` <- function(x, i, j, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[<-")
+
+    class(result) <- c("cbc_design", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
+
+#' @export
+`names<-.cbc_design` <- function(x, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("names<-")
+
+    class(result) <- c("cbc_design", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
+
+# ============================================================================
+# Attribute preservation methods for cbc_choices
+# ============================================================================
+
+#' @export
+`[.cbc_choices` <- function(x, i, j, drop = FALSE) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[")
+
+    if (is.data.frame(result)) {
+        class(result) <- c("cbc_choices", "data.frame")
+
+        custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+        for (attr_name in custom_attr_names) {
+            attr(result, attr_name) <- custom_attrs[[attr_name]]
+        }
+    }
+
+    return(result)
+}
+
+#' @export
+`[<-.cbc_choices` <- function(x, i, j, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("[<-")
+
+    class(result) <- c("cbc_choices", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
+
+#' @export
+`names<-.cbc_choices` <- function(x, value) {
+    custom_attrs <- attributes(x)
+    standard_attrs <- c("names", "row.names", "class")
+
+    result <- NextMethod("names<-")
+
+    class(result) <- c("cbc_choices", "data.frame")
+
+    custom_attr_names <- setdiff(names(custom_attrs), standard_attrs)
+    for (attr_name in custom_attr_names) {
+        attr(result, attr_name) <- custom_attrs[[attr_name]]
+    }
+
+    return(result)
+}
