@@ -55,11 +55,11 @@ validate_choice_structure <- function(choices, design, has_nochoice = FALSE) {
   if (has_nochoice) {
     expect_true("no_choice" %in% names(choices))
     expect_true(all(choices$no_choice %in% c(0, 1)))
+  } else {
+    # Should preserve all design columns
+    design_cols <- setdiff(names(design), "choice")
+    expect_true(all(design_cols %in% names(choices)))
   }
-
-  # Should preserve all design columns
-  design_cols <- setdiff(names(design), "choice")
-  expect_true(all(design_cols %in% names(choices)))
 }
 
 # Statistical test for parameter recovery
@@ -243,13 +243,7 @@ test_that("Fixed parameters can be recovered accurately", {
     data = choices,
     outcome = 'choice',
     obsID = 'obsID',
-    pars = c(
-      "price",
-      "typeGala",
-      "typeHoneycrisp",
-      "freshnessAverage",
-      "freshnessExcellent"
-    )
+    pars = c("price", "type", "freshness")
   )
 
   # Test parameter recovery
@@ -294,14 +288,8 @@ test_that("Random parameters can be recovered accurately", {
     data = choices,
     outcome = 'choice',
     obsID = 'obsID',
-    pars = c(
-      "price",
-      "typeGala",
-      "typeHoneycrisp",
-      "freshnessAverage",
-      "freshnessExcellent"
-    ),
-    randPars = c(price = "n", freshnessAverage = "n", freshnessExcellent = "n"),
+    pars = c("price", "type", "freshness"),
+    randPars = c(price = "n", freshness = "n"),
     panelID = "respID"
   )
 
@@ -370,7 +358,8 @@ test_that("No-choice parameters can be recovered accurately", {
     no_choice = TRUE
   )
 
-  choices <- cbc_choices(design, true_priors)
+  choices <- cbc_choices(design, true_priors) |>
+    cbc_encode(coding = 'dummy')
 
   # Estimate model with no-choice
   model <- logitr::logitr(
@@ -437,7 +426,7 @@ test_that("Interaction parameters can be recovered accurately", {
     data = choices,
     outcome = 'choice',
     obsID = 'obsID',
-    pars = c("price", "meatSteak", "wineRed", "meatSteak*wineRed")
+    pars = c("price", "meat*wine")
   )
 
   # Build true parameter vector including interaction
